# Python Multigit<a name="top"></a>

This package offers a simple way of managing *"workspaces"* integrating multiple git repos starting from a top one, and without the need of difficult *"arcanes"* like *git submodules*, *git-subtree*, etc.: you only need to declare your intended layout in a YAML file, and let this script (**multigit**) do its job.

Read the [full documentation on GitHub](https://github.com/jmnavarrol/python-multigit#readme).

Also see the [simplest-git-subrepos README](https://github.com/jmnavarrol/simplest-git-subrepos#readme) for a long-wired rationale.
